==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/Effect/soxr/translations/soxr_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="32"/>
        <source>SoX Resampler Plugin</source>
        <translation>Plugin SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Acerca do plugin SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="54"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Plugin Qmmp SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="55"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SoX Resampler Settings</source>
        <translation>Configuracións SoX Resampler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Sample Rate (Hz):</source>
        <translation>Frecuencia (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="49"/>
        <source>Quality:</source>
        <translation>Calidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Moi alto</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Effect/soxr/translations/soxr_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>EffectSoXRFactory</name>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="31"/>
        <source>SoX Resampler Plugin</source>
        <translation>Plugin SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="52"/>
        <source>About SoX Resampler Plugin</source>
        <translation>Acerca do plugin SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="53"/>
        <source>Qmmp SoX Resampler Plugin</source>
        <translation>Plugin Qmmp SoX Resampler</translation>
    </message>
    <message>
        <location filename="../effectsoxrfactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SoX Resampler Settings</source>
        <translation>Configuracións SoX Resampler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Sample Rate (Hz):</source>
        <translation>Frecuencia (Hz):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="49"/>
        <source>Quality:</source>
        <translation>Calidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>Quick</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>Low</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Very High</source>
        <translation>Moi alto</translation>
    </message>
</context>
</TS>
